core/core library

Classes

MuscleHelper
A helper class to facilitate mapping Muscle enum values to SVG path data.
MuscleHighlight<T extends Muscle>
Represents a configuration for highlighting a specific muscle.
SvgElement
Base class for SVG elements such as paths and groups.
SvgFileWriter
A class responsible for generating SVG file content by building an XML structure.
SvgGroup
Represents an SVG group element (<g>).
SvgPath
Represents an SVG path element (<path>).
SvgPathReader
A utility class for reading and parsing path data from SVG files.

Enums

BodyView
Represents the perspective or view of the human body.
Muscle
Represents individual muscles in the human body.
MusclePosition
Represents the lateral position of a muscle on the body.

Extensions

ColorHex on Color
An extension on the Color class to provide conversion to a hex string.