isBack method
Returns true if the muscle is visible from the back view.
Implementation
bool isBack() => _view == BodyView.back || _view == BodyView.both;
Returns true if the muscle is visible from the back view.
bool isBack() => _view == BodyView.back || _view == BodyView.both;