isFront method
Returns true if the muscle is visible from the front view.
Implementation
bool isFront() => _view == BodyView.front || _view == BodyView.both;
Returns true if the muscle is visible from the front view.
bool isFront() => _view == BodyView.front || _view == BodyView.both;