MuscleHighlight<T extends Muscle> class
Represents a configuration for highlighting a specific muscle.
Constructors
- MuscleHighlight({required MusclePosition position, required Color color, required double opacity, required T muscle})
- Creates a new MuscleHighlight configuration.
Properties
- color → Color
-
The color to use for the highlight.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- muscle → T
-
The muscle to be highlighted.
final
- opacity → double
-
The opacity of the highlight color.
final
- position → MusclePosition
-
The position (left, right, or both) of the muscle to highlight.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{T? muscle, MusclePosition? position, Color? color, double? opacity}) → MuscleHighlight< T> - Creates a copy of this MuscleHighlight with updated fields.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited