MusclePosition enum

Represents the lateral position of a muscle on the body.

Inheritance
Available extensions

Values

left → const MusclePosition

Positioned on the left side of the body.

Positioned on the right side of the body.

both → const MusclePosition

Positioned on both sides of the body.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MusclePosition>
A constant List of the values in this enum, in order of their declaration.