SvgGroup class
Represents an SVG group element (<g>).
- Inheritance
-
- Object
- SvgElement
- SvgGroup
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addAttribute(
String key, String value) → void -
Adds a custom attribute to the element.
inherited
-
addAttributes(
Map< String, String> attributes) → void -
Adds multiple attributes to the element.
inherited
-
addChild(
SvgElement child) → void -
Adds a child SvgElement to this element.
inherited
-
addChildren(
Iterable< SvgElement> children) → void -
Adds multiple child SvgElements to this element.
inherited
-
addStyle(
String key, String value) → void -
Adds a single CSS-style attribute to the element.
inherited
-
addStyles(
Map< String, String> styles) → void -
Adds multiple CSS-style attributes to the element.
inherited
-
build(
) → XmlElement -
Builds and returns the
XmlElementfor this element.inherited -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns the XML string representation of this element.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited