SvgPath constructor
Creates an SvgPath with the specified id and path data d.
Initializes the path with default stroke and fill styles.
Implementation
SvgPath({required super.id, required this.d}) : super(tag: 'path') {
super.addAttribute('d', d);
addStyles({
'display': 'inline',
'fill': 'none',
'stroke': '#000000',
'stroke-width': '0.2',
'stroke-linecap': 'round',
'stroke-linejoin': 'round',
'stroke-dasharray': 'none',
'stroke-dashoffset': '0',
'stroke-opacity': '1',
'paint-order': 'stroke fill markers',
});
}