SvgPathReader class

A utility class for reading and parsing path data from SVG files.

It provides mechanisms to retrieve SVG path 'd' attributes by ID, with support for group elements and automatic caching.

Properties

hashCode int
The hash code for this object.
no setterinherited
height double
The intrinsic height of the SVG defined in the 'height' attribute.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
width double
The intrinsic width of the SVG defined in the 'width' attribute.
no setter

Methods

getPathDs(String pathId) List<String>
Returns a list of path 'd' attributes associated with the given pathId.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

female(BodyView view) SvgPathReader
Returns an SvgPathReader for the female body based on the specified view.
femaleBack() SvgPathReader
Returns an SvgPathReader for the female back view.
femaleFront() SvgPathReader
Returns an SvgPathReader for the female front view.
male(BodyView view) SvgPathReader
Returns an SvgPathReader for the male body based on the specified view.
maleBack() SvgPathReader
Returns an SvgPathReader for the male back view.
maleFront() SvgPathReader
Returns an SvgPathReader for the male front view.