Muscle enum
Represents individual muscles in the human body.
Each muscle is associated with a BodyView indicating where it is visible.
Values
- triceps → const Muscle
-
The triceps brachii muscle, located on the back of the upper arm.
const Muscle(view: BodyView.back) - levatorScapulae → const Muscle
-
The levator scapulae muscle, which lifts the scapula.
const Muscle(view: BodyView.back) - trapezius → const Muscle
-
The trapezius muscle, a large superficial muscle that extends longitudinally from the occipital bone to the lower thoracic vertebrae.
const Muscle(view: BodyView.back) - posteriorDeltoid → const Muscle
-
The posterior part of the deltoid muscle.
const Muscle(view: BodyView.back) - infraspinatus → const Muscle
-
The infraspinatus muscle, a thick triangular muscle that occupies the chief part of the infraspinatous fossa.
const Muscle(view: BodyView.back) - teresMinor → const Muscle
-
The teres minor muscle, a narrow, elongated muscle of the rotator cuff.
const Muscle(view: BodyView.back) - teresMajor → const Muscle
-
The teres major muscle, a muscle of the upper limb.
const Muscle(view: BodyView.back) - anconeus → const Muscle
-
The anconeus muscle, a small muscle on the posterior aspect of the elbow joint.
const Muscle(view: BodyView.back) - flexorCarpiUlnaris → const Muscle
-
The flexor carpi ulnaris muscle, a muscle of the human forearm that acts to flex and adduct the hand.
const Muscle(view: BodyView.back) - extensorCarpiUlnaris → const Muscle
-
The extensor carpi ulnaris muscle, a muscle of the forearm that acts to extend and adduct at the wrist.
const Muscle(view: BodyView.back) - extensorDigitorum → const Muscle
-
The extensor digitorum muscle, a muscle of the posterior forearm that extends the medial four digits of the hand.
const Muscle(view: BodyView.back) - externalOblique → const Muscle
-
The external oblique muscle, the largest and most superficial of the three flat abdominal muscles.
const Muscle(view: BodyView.back) - latissimusDorsi → const Muscle
-
The latissimus dorsi muscle, the larger, flat, dorso-lateral muscle on the trunk.
const Muscle(view: BodyView.both) - gluteusMedius → const Muscle
-
The gluteus medius muscle, one of the three gluteal muscles.
const Muscle(view: BodyView.back) - gluteusMaximus → const Muscle
-
The gluteus maximus muscle, the main extensor muscle of the hip.
const Muscle(view: BodyView.back) - iliotibialTact → const Muscle
-
The iliotibial tract, a longitudinal fibrous reinforcement of the fascia lata.
const Muscle(view: BodyView.back) - bicepsFemoris → const Muscle
-
The biceps femoris muscle, a muscle of the thigh located to the posterior, or back.
const Muscle(view: BodyView.back) - semitendinosus → const Muscle
-
The semitendinosus muscle, one of the three hamstring muscles.
const Muscle(view: BodyView.back) - adductorMagnus → const Muscle
-
The adductor magnus muscle, a large triangular muscle, situated on the medial side of the thigh.
const Muscle(view: BodyView.back) - semimebranosus → const Muscle
-
The semimembranosus muscle, the most medial of the three hamstring muscles.
const Muscle(view: BodyView.back) - gastrocnemius → const Muscle
-
The gastrocnemius muscle, a powerful superficial bipennate muscle that is in the back part of the lower leg.
const Muscle(view: BodyView.both) - soleus → const Muscle
-
The soleus muscle, a powerful muscle in the back part of the lower leg.
const Muscle(view: BodyView.both) - digastric → const Muscle
-
The digastric muscle, a small muscle located under the jaw.
const Muscle(view: BodyView.front) - sternocleidomastoid → const Muscle
-
The sternocleidomastoid muscle, one of the largest and most superficial cervical muscles.
const Muscle(view: BodyView.front) - scalene → const Muscle
-
The scalene muscles, a group of three pairs of muscles in the lateral neck.
const Muscle(view: BodyView.front) - upperTrapezius → const Muscle
-
The upper portion of the trapezius muscle.
const Muscle(view: BodyView.front) - deltoid → const Muscle
-
The deltoid muscle, the muscle forming the rounded contour of the human shoulder.
const Muscle(view: BodyView.front) - biceps → const Muscle
-
The biceps brachii muscle, a two-headed muscle that lies on the upper arm between the shoulder and the elbow.
const Muscle(view: BodyView.front) - pectolarisMajor → const Muscle
-
The pectoralis major muscle, a thick, fan-shaped muscle, situated at the chest of the human body.
const Muscle(view: BodyView.front) - rectusAbdominis → const Muscle
-
The rectus abdominis muscle, also known as the "abs".
const Muscle(view: BodyView.front) - externalAbdominalOblique → const Muscle
-
The external abdominal oblique muscle.
const Muscle(view: BodyView.front) - adductorLongus → const Muscle
-
The adductor longus muscle, a skeletal muscle located in the thigh.
const Muscle(view: BodyView.front) - tensorFasciaeLatae → const Muscle
-
The tensor fasciae latae muscle, a muscle of the thigh.
const Muscle(view: BodyView.front) - pectineus → const Muscle
-
The pectineus muscle, a flat, quadrangular muscle, situated at the anterior part of the medial and upper aspect of the thigh.
const Muscle(view: BodyView.front) - iliopsoas → const Muscle
-
The iliopsoas muscle, the joined psoas and iliacus muscles.
const Muscle(view: BodyView.front) - gracilis → const Muscle
-
The gracilis muscle, the most superficial muscle on the medial side of the thigh.
const Muscle(view: BodyView.front) - rectusFemoris → const Muscle
-
The rectus femoris muscle, one of the four quadriceps muscles of the human body.
const Muscle(view: BodyView.front) - vastusMedialis → const Muscle
-
The vastus medialis muscle, an extensor muscle located medially in the thigh that extends the knee.
const Muscle(view: BodyView.front) - vastusLateralis → const Muscle
-
The vastus lateralis muscle, the largest and most powerful part of the quadriceps femoris.
const Muscle(view: BodyView.front) - sartorius → const Muscle
-
The sartorius muscle, the longest muscle in the human body.
const Muscle(view: BodyView.front) - tibialisAnterior → const Muscle
-
The tibialis anterior muscle, a muscle that originates in the upper two-thirds of the lateral surface of the tibia.
const Muscle(view: BodyView.front) - anteriorDeltoid → const Muscle
-
The anterior part of the deltoid muscle.
const Muscle(view: BodyView.front) - extensorDigitorumLongus → const Muscle
-
The extensor digitorum longus muscle, a pennate muscle on the lateral part of the front of the leg.
const Muscle(view: BodyView.front) - peroneusLongus → const Muscle
-
The peroneus longus muscle, a superficial muscle in the lateral compartment of the leg.
const Muscle(view: BodyView.front) - brachialis → const Muscle
-
The brachialis muscle, a muscle in the upper arm that flexes the elbow joint.
const Muscle(view: BodyView.front) - brachioradialis → const Muscle
-
The brachioradialis muscle, a muscle of the forearm that flexes the forearm at the elbow.
const Muscle(view: BodyView.front) - pronatorTeres → const Muscle
-
The pronator teres muscle, a muscle of the human body that is located in the forearm.
const Muscle(view: BodyView.front) - flexorFasciaeLatae → const Muscle
-
The flexor fasciae latae muscle.
const Muscle(view: BodyView.front)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
isBack(
) → bool - Returns true if the muscle is visible from the back view.
-
isForView(
BodyView view) → bool -
Returns true if the muscle is visible in the specified
view. -
isFront(
) → bool - Returns true if the muscle is visible from the front view.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited