MuscleHelper class
A helper class to facilitate mapping Muscle enum values to SVG path data.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
leftSvgPath
→ List<
String> -
Returns the SVG path data for the left side of this muscle.
no setter
- name → String
-
The name of the muscle (corresponds to the enum member name).
no setter
-
rightSvgPath
→ List<
String> -
Returns the SVG path data for the right side of this muscle.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- svgId → String
-
The snake_case version of the muscle name, used for SVG IDs.
no setter
-
svgPaths
→ List<
String> -
Returns the SVG path data for this muscle (could be both or a single centered path).
no setter
Methods
-
getSvgPath(
MusclePosition? position) → List< String> -
Returns the raw SVG path data string(s) for the specified
position. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toSvgElement(
MusclePosition? position, {Color fillColor = Colors.transparent, double fillOpacity = 0, Color strokeColor = Colors.black, double strokeWidth = 1, String? idSuffix}) → SvgElement -
Converts this muscle helper into an SvgElement for a specific
position.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromHighlight<
T extends Muscle> (MuscleHighlight< T> highlight, SvgPathReader pathReader, {Color? strokeColor, double? strokeWidth, String? idSuffix}) → SvgElement - Creates an SvgElement from a MuscleHighlight object.
-
fromMuscle(
Muscle muscle, SvgPathReader svgPathReader) → MuscleHelper - Factory-like method to get a MuscleHelper from a Muscle.
-
getInstance(
Muscle muscle, SvgPathReader svgPathReader) → MuscleHelper -
Returns a cached or new instance of MuscleHelper for the given
muscleandsvgPathReader.