MuscleHelper class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
leftSvgPath
→ List<
String> -
no setter
- name → String
-
no setter
-
rightSvgPath
→ List<
String> -
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- svgId → String
-
no setter
-
svgPaths
→ List<
String> -
no setter
Methods
-
getSvgPath(
MusclePosition? position) → List< String> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
toSvgElement(
MusclePosition? position, {Color fillColor = Colors.transparent, double fillOpacity = 0, Color strokeColor = Colors.black, double strokeWidth = 1, String? idSuffix}) → SvgElement
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromHighlight<
T extends Muscle> (MuscleHighlight< T> highlight, SvgPathReader pathReader, {Color? strokeColor, double? strokeWidth, String? idSuffix}) → SvgElement -
fromMuscle(
Muscle muscle, SvgPathReader svgPathReader) → MuscleHelper -
getInstance(
Muscle muscle, SvgPathReader svgPathReader) → MuscleHelper