MuscleHighlight<T extends Muscle> class

Constructors

MuscleHighlight({required MusclePosition position, required Color color, required double opacity, required T muscle})

Properties

color Color
final
hashCode int
The hash code for this object.
no setterinherited
muscle → T
final
opacity double
final
position MusclePosition
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({T? muscle, MusclePosition? position, Color? color, double? opacity}) MuscleHighlight<T>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited