SvgFileWriter class final
A class responsible for generating SVG file content by building an XML structure.
Constructors
- SvgFileWriter(Size _size)
-
Creates a new SvgFileWriter with the specified
size.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addElement(
SvgElement element) → void - Adds a single SvgElement to be included in the SVG.
-
addElements(
Iterable< SvgElement> elements) → void - Adds multiple SvgElements to be included in the SVG.
-
build(
) → XmlDocument -
Builds the
XmlDocumentrepresenting the SVG. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
Returns the SVG content as a formatted XML string.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited